@@ -14,12 +14,12 @@
 #include <qcommandlineparser.h>
 
 #include <KAboutData>
+#include <PlasmaQuick/SharedQmlEngine>
 #include <QQmlContext>
 #include <QQmlEngine>
 #include <QQmlExpression>
 #include <QQmlProperty>
 #include <QQuickWindow>
-#include <kdeclarative/qmlobject.h>
 #include <kpackage/package.h>
 #include <kpackage/packageloader.h>
 
@@ -45,7 +45,7 @@ int main(int argc, char **argv)
     const QString packagePath("org.kde.plasma.lookandfeelexplorer");
 
     // usually we have an ApplicationWindow here, so we do not need to create a window by ourselves
-    KDeclarative::QmlObject obj;
+    PlasmaQuick::SharedQmlEngine obj;
     obj.setTranslationDomain(packagePath);
     obj.setInitializationDelayed(true);
     obj.engine()->rootContext()->setContextProperty("commandlineTheme", parser.value(themeOption));
@@ -71,7 +71,7 @@ int main(int argc, char **argv)
     KAboutData aboutData(data.pluginId(), data.name(), data.version(), data.description(), KAboutLicense::byKeyword(data.license()).key());
 
     for (auto author : data.authors()) {
-        aboutData.addAuthor(author.name(), author.task(), author.emailAddress(), author.webAddress(), author.ocsUsername());
+        aboutData.addAuthor(author.name(), author.task(), author.emailAddress(), author.webAddress());
     }
 
     // The root is not a window?
